Enum gtld_data::GtldKind [] [src]

pub enum GtldKind {
    CountryCode,
    GenericRestricted,
    Generic,
    Infrastructure,
    Sponsored,
    Test,
}

The type of what a Gtld is. Each Gtld has a different type, with each having a different purpose.

Wikipedia has a good summary of the differences of each:

https://en.wikipedia.org/wiki/Top-level_domain#Types

Derives Clone, Debug, and PartialEq.

Variants

CountryCode

ccTLD: Two-letter domains established for countries or territories.

GenericRestricted

grTLD: domains managed under official ICANN accredited registrars.

Generic

gTLD: Top-level domains with three or more characters.

Infrastructure

ARPA: Consists of one domain, the Address and Routing Parameter Area.

Sponsored

Domains that are proposed and sponsored by private agencies or organizations.

Test

Domains installed under .test for testing purposes in the IDN development process.