Struct gtld_data::Gtld
[−]
[src]
pub struct Gtld<'a> {
pub domain: &'a str,
pub kind: GtldKind,
pub organization: &'a str,
}Representation of each Gtld with its three key pieces of data:
- domain:
strof the domain name for thisGtld, such ascomorpw. - kind:
GtldKindenum value of the type ofGtldthat this is. For technical purposes, this is renamed fromtypetokind. - organization:
strof the name of the organization that represents thisGtld.
Derives Clone and Debug.
Fields
domain: &'a str
kind: GtldKind
organization: &'a str