Enum gtld_data::GtldKind
[−]
[src]
pub enum GtldKind {
CountryCode,
GenericRestricted,
Generic,
Infrastructure,
Sponsored,
Test,
}The type of what a Gtld is. Each Gtld has a different type, with each
having a different purpose.
Wikipedia has a good summary of the differences of each:
https://en.wikipedia.org/wiki/Top-level_domain#Types
Derives Clone, Debug, and PartialEq.
Variants
CountryCodeccTLD: Two-letter domains established for countries or territories.
GenericRestrictedgrTLD: domains managed under official ICANN accredited registrars.
GenericgTLD: Top-level domains with three or more characters.
InfrastructureARPA: Consists of one domain, the Address and Routing Parameter Area.
SponsoredDomains that are proposed and sponsored by private agencies or organizations.
TestDomains installed under .test for testing purposes in the IDN development process.